Math

Struct Math 

pub struct Math<T>(/* private fields */);
Zero-sized struct for performing mathematical calculations on floating points.

Implementations

Source

impl<T: Float> Math<T>

pub fn circumcircle(p1: Point<T>, p2: Point<T>, p3: Point<T>) -> (Point<T>, T)

Computes the circumcircle given 3 points.

pub fn point_on_line(a: Point<T>, b: Point<T>, len: T) -> Point<T>

Get the point on the line segment on p1, p2 that ends after length

pub fn is_line(a: Point<T>, b: Point<T>, c: Point<T>) -> bool

Checks if a, b, and c are all on the same line

pub fn catmull_find_point( val1: Point<T>, val2: Point<T>, val3: Point<T>, val4: Point<T>, t: T, ) -> Point<T>

Finds a point on the spline at the position of a parameter.

The parameter at which to find the point on the spline, in the range [0, 1]. The point on the spline at .