pub struct Math<T>(/* private fields */);Expand description
Zero-sized struct for performing mathematical calculations on floating points.
Implementations
Sourceimpl<T: Float> Math<T>
impl<T: Float> Math<T>
Sourcepub fn circumcircle(p1: Point<T>, p2: Point<T>, p3: Point<T>) -> (Point<T>, T)
pub fn circumcircle(p1: Point<T>, p2: Point<T>, p3: Point<T>) -> (Point<T>, T)
Computes the circumcircle given 3 points.
Sourcepub fn point_on_line(a: Point<T>, b: Point<T>, len: T) -> Point<T>
pub fn point_on_line(a: Point<T>, b: Point<T>, len: T) -> Point<T>
Get the point on the line segment on p1, p2 that ends after length